# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal
from .x_text_range import XTextRange as XTextRange_9a910ab7

class XTextCursor(XTextRange_9a910ab7):
    """
    extends a text range by method to modify its position.

    See Also:
        `API XTextCursor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XTextCursor.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.text.XTextCursor']

    def collapseToEnd(self) -> None:
        """
        sets the start of the position to the end.
        """
    def collapseToStart(self) -> None:
        """
        sets the end of the position to the start.
        """
    def goLeft(self, nCount: int, bExpand: bool) -> bool:
        """
        moves the cursor the specified number of characters to the left.
        
        Note: Even if the command was not completed successfully it may be completed partially. E.g. if it was required to move 5 characters but it is only possible to move 3 FALSE will be returned and the cursor moves only those 3 characters.
        """
    def goRight(self, nCount: int, bExpand: bool) -> bool:
        """
        moves the cursor the specified number of characters to the right.
        
        Note: Even if the command was not completed successfully it may be completed partially. E.g. if it was required to move 5 characters but it is only possible to move 3 FALSE will be returned and the cursor moves only those 3 characters.
        """
    def gotoEnd(self, bExpand: bool) -> None:
        """
        moves the cursor to the end of the text.
        """
    def gotoRange(self, xRange: 'XTextRange_9a910ab7', bExpand: bool) -> None:
        """
        moves or expands the cursor to a specified TextRange.
        """
    def gotoStart(self, bExpand: bool) -> None:
        """
        moves the cursor to the start of the text.
        """
    def isCollapsed(self) -> bool:
        """
        determines if the start and end positions are the same.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.style
from .character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from .style import Style as Style_7336094a

class CharacterStyle(CharacterProperties_1d4f0ef3, Style_7336094a):
    """
    Service Class

    specifies a style sheet for characters within a com.sun.star.text.Text.

    See Also:
        `API CharacterStyle <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1CharacterStyle.html>`_
    """
    @property
    def CharDiffHeight(self) -> float:
        """
        This value contains the character height as difference in point to the height of the character in the parent style.
        """
    @property
    def CharDiffHeightAsian(self) -> float:
        """
        This value contains the character height as difference in point to the height of the character in the parent style in Asian text.
        """
    @property
    def CharDiffHeightComplex(self) -> float:
        """
        This value contains the character height as difference in point to the height of the character in the parent style in complex text.
        """
    @property
    def CharPropHeight(self) -> int:
        """
        This value contains the character height as percentage value relative to the height of the character in the parent style.
        """
    @property
    def CharPropHeightAsian(self) -> int:
        """
        This value contains the character height as percentage value relative to the height of the character in the parent style in Asian text.
        """
    @property
    def CharPropHeightComplex(self) -> int:
        """
        This value contains the character height as percentage value relative to the height of the character in the parent style in complex text.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3

class XTabListener(XEventListener_c7230c4a):
    """
    such listener will be informed if tab's was inserted/removed from an XSimpleTabController instance or if the properties of a tab was changed.

    See Also:
        `API XTabListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XTabListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XTabListener']

    def activated(self, ID: int) -> None:
        """
        a tab was activated (e.g.
        
        by using mouse/keyboard or method XSimpleTabController.activateTab()
        """
    def changed(self, ID: int, Properties: 'typing.Tuple[NamedValue_a37a0af3, ...]') -> None:
        """
        a tab was changed within its properties.
        """
    def deactivated(self, ID: int) -> None:
        """
        a tab was deactivated, because another tab became the new active state.
        """
    def inserted(self, ID: int) -> None:
        """
        a new tab was inserted.
        """
    def removed(self, ID: int) -> None:
        """
        a tab was removed.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.logging
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .log_record import LogRecord as LogRecord_b0c20b70

class XLogFormatter(ABC):
    """
    specifies the interface to be used for formatting log records
    
    **since**
    
        OOo 2.3

    See Also:
        `API XLogFormatter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1logging_1_1XLogFormatter.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.logging.XLogFormatter']

    def format(self, Record: 'LogRecord_b0c20b70') -> str:
        """
        formats the given log record for output
        
        A XLogHandler will call this method to format a given log record. The resulting string will be emitted to the handler's output channel, without processing it any further (except possibly encoding it with the handler's Encoding).
        """
    def getHead(self) -> str:
        """
        returns the header string for the log
        
        This can be used to generate a header string, which by the XLogHandler is emitted to its output channel before actually logging any concrete LogRecord.
        
        For instance, a formatter might produce table-like plain text output, and could return a table-head string (potentially including line breaks) here.
        """
    def getTail(self) -> str:
        """
        returns the footer string for the log
        
        This can be used to generate a footer string, which by the XLogHandler is emitted to its output channel before it is finally being closed.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
from .x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0

class XModifiable(XModifyBroadcaster_fd990df0):
    """
    makes the modify state of the object accessible.
    
    Additionally, it makes it possible to register listener objects, which get notification whenever the status or content of the object changes.

    See Also:
        `API XModifiable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XModifiable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XModifiable']

    def isModified(self) -> bool:
        """
        The modification is always in relation to a certain state (i.e., the initial, loaded, or last stored version).
        """
    def setModified(self, bModified: bool) -> None:
        """
        sets the status of the modified-flag from outside of the object.

        Raises:
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .docking_data import DockingData as DockingData_98da0a8d
    from .docking_event import DockingEvent as DockingEvent_a4210b15
    from .end_docking_event import EndDockingEvent as EndDockingEvent_c6400c2c
    from .end_popup_mode_event import EndPopupModeEvent as EndPopupModeEvent_e0bd0d06
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XDockableWindowListener(XEventListener_c7230c4a):
    """
    makes it possible to receive docking events.

    See Also:
        `API XDockableWindowListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XDockableWindowListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XDockableWindowListener']

    def closed(self, e: 'EventObject_a3d70b03') -> None:
        """
        is invoked when the window was actively closed
        """
    def docking(self, e: 'DockingEvent_a4210b15') -> 'DockingData_98da0a8d':
        """
        is invoked during the docking procedure when the window has been moved.
        
        on return the DockingData must contain either the old tracking rectangle or a changed rectangle if required, additionally it must indicate if the window should be docked or floating
        
        Note: the tracking rectangle indicates to the user where the window would be placed if he releases the mouse.
        """
    def endDocking(self, e: 'EndDockingEvent_c6400c2c') -> None:
        """
        is invoked when the docking procedure ends.
        
        aWindowRect contains the new position and size of the window
        """
    def endPopupMode(self, e: 'EndPopupModeEvent_e0bd0d06') -> None:
        """
        is invoked when the window currently is in pop-up mode and wants to be undocked or closed
        """
    def prepareToggleFloatingMode(self, e: 'EventObject_a3d70b03') -> bool:
        """
        is invoked when the floating mode is about to be changed between floating and docked or vice versa
        
        if returned FALSE the floating mode will not be changed
        """
    def startDocking(self, e: 'DockingEvent_a4210b15') -> None:
        """
        is invoked when the docking procedure starts.
        """
    def toggleFloatingMode(self, e: 'EventObject_a3d70b03') -> None:
        """
        is invoked when the floating mode is changed between floating and docked or vice versa
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal


class GeneralFunction2(object):
    """
    Const

    used to specify a function to be calculated from values.
    
    **since**
    
        LibreOffice 5.3

    See Also:
        `API GeneralFunction2 <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html>`_
    """
    NONE: Literal[0]
    """
    nothing is calculated.
    """
    AUTO: Literal[1]
    """
    function is determined automatically.
    
    If the values are all numerical, SUM is used, otherwise COUNT.
    """
    SUM: Literal[2]
    """
    sum of all numerical values is calculated.
    """
    COUNT: Literal[3]
    """
    all values, including non-numerical values, are counted.
    """
    AVERAGE: Literal[4]
    """
    average of all numerical values is calculated.
    """
    MAX: Literal[5]
    """
    maximum value of all numerical values is calculated.
    """
    MIN: Literal[6]
    """
    minimum value of all numerical values is calculated.
    """
    PRODUCT: Literal[7]
    """
    product of all numerical values is calculated.
    """
    COUNTNUMS: Literal[8]
    """
    numerical values are counted.
    """
    STDEV: Literal[9]
    """
    standard deviation is calculated based on a sample.
    """
    STDEVP: Literal[10]
    """
    standard deviation is calculated based on the entire population.
    """
    VAR: Literal[11]
    """
    variance is calculated based on a sample.
    """
    VARP: Literal[12]
    """
    variance is calculated based on the entire population.
    """
    MEDIAN: Literal[13]
    """
    median of all numerical values is calculated.
    
    **since**
    
        LibreOffice 5.3
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
from .x_control import XControl as XControl_7a9c098d
from .x_control_container import XControlContainer as XControlContainer_e22d0d30
from .x_dialog2 import XDialog2 as XDialog2_79cb092e
from .x_top_window import XTopWindow as XTopWindow_8ebb0a57
from .x_window import XWindow as XWindow_713b0924

class XUnoControlDialog(XControl_7a9c098d, XControlContainer_e22d0d30, XDialog2_79cb092e, XTopWindow_8ebb0a57, XWindow_713b0924):
    """
    The interface for the UnoControlDialog service.
    
    This service actually implements a whole whack of interfaces. This is the just the subset that our code needs.
    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API XUnoControlDialog <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XUnoControlDialog.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XUnoControlDialog']





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .calendar_item import CalendarItem as CalendarItem_a86c0af1


class Calendar(object):
    """
    Struct Class

    A calendar as returned in a sequence by XLocaleData.getAllCalendars().

    See Also:
        `API Calendar <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1Calendar.html>`_
    """
    typeName: Literal['com.sun.star.i18n.Calendar']

    def __init__(self, Days: typing.Optional[typing.Tuple[CalendarItem_a86c0af1, ...]] = ..., Months: typing.Optional[typing.Tuple[CalendarItem_a86c0af1, ...]] = ..., Eras: typing.Optional[typing.Tuple[CalendarItem_a86c0af1, ...]] = ..., StartOfWeek: typing.Optional[str] = ..., MinimumNumberOfDaysForFirstWeek: typing.Optional[int] = ..., Default: typing.Optional[bool] = ..., Name: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Days (typing.Tuple[CalendarItem, ...], optional): Days value.
            Months (typing.Tuple[CalendarItem, ...], optional): Months value.
            Eras (typing.Tuple[CalendarItem, ...], optional): Eras value.
            StartOfWeek (str, optional): StartOfWeek value.
            MinimumNumberOfDaysForFirstWeek (int, optional): MinimumNumberOfDaysForFirstWeek value.
            Default (bool, optional): Default value.
            Name (str, optional): Name value.
        """


    @property
    def Days(self) -> typing.Tuple[CalendarItem_a86c0af1, ...]:
        """
        the days of the week, see also CalendarItem.
        """


    @property
    def Months(self) -> typing.Tuple[CalendarItem_a86c0af1, ...]:
        """
        the months of the year, see also CalendarItem.
        """


    @property
    def Eras(self) -> typing.Tuple[CalendarItem_a86c0af1, ...]:
        """
        the possible eras, see also CalendarItem.
        """


    @property
    def StartOfWeek(self) -> str:
        """
        the ID of the day with which the week begins.
        """


    @property
    def MinimumNumberOfDaysForFirstWeek(self) -> int:
        """
        how many days must reside in the first week of a year.
        """


    @property
    def Default(self) -> bool:
        """
        if this is the default calendar for a given locale.
        """


    @property
    def Name(self) -> str:
        """
        the name of the calendar, for example, Gregorian.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.xml.sax
from typing_extensions import Literal
from .x_document_handler import XDocumentHandler as XDocumentHandler_9b90e28

class XExtendedDocumentHandler(XDocumentHandler_9b90e28):
    """
    this interface does not conform to the SAX-standard.
    
    Note: Whether or not every callback is supported is dependent on the parser implementation.

    See Also:
        `API XExtendedDocumentHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XExtendedDocumentHandler.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.sax.XExtendedDocumentHandler']

    def allowLineBreak(self) -> None:
        """
        informs a writer that it is allowable to insert a line break and indentation before the next XDocumentHandler-call.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def comment(self, sComment: str) -> None:
        """
        receives notification about a comment in the XML-source.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def endCDATA(self) -> None:
        """
        informs about the end of a CDATA-Section.
        
        Note that startCDATA/endCDATA MUST NOT enclose any startElement/endElement-call!

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def startCDATA(self) -> None:
        """
        receives notification about the start of a CDATA section in the XML-source.
        
        Any string coming in via character handler may include chars, that would otherwise be interpreted as markup.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def unknown(self, sString: str) -> None:
        """
        notifies that any characters that cannot be handled by other callback methods are announced through this method.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.media
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from .x_frame_grabber import XFrameGrabber as XFrameGrabber_c56f0c00
    from .x_player_window import XPlayerWindow as XPlayerWindow_c7130c45

class XPlayer(ABC):
    """
    is the multimedia stream handling interface.
    
    This allows to perform every basic operation on videos and sounds.

    See Also:
        `API XPlayer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1media_1_1XPlayer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.media.XPlayer']

    def createFrameGrabber(self) -> 'XFrameGrabber_c56f0c00':
        """
        gets a frame grabber for this stream.
        """
    def createPlayerWindow(self, aArguments: 'typing.Tuple[object, ...]') -> 'XPlayerWindow_c7130c45':
        """
        gets a new player window for this stream control
        """
    def getDuration(self) -> float:
        """
        gets the stream length
        """
    def getMediaTime(self) -> float:
        """
        gets the current position of the cursor in the stream
        """
    def getPreferredPlayerWindowSize(self) -> 'Size_576707ef':
        """
        gets the preferred window size
        """
    def getVolumeDB(self) -> int:
        """
        gets the current audio volume in decibel
        """
    def isMute(self) -> bool:
        """
        gets whether the volume is temporarily down to 0 or not.
        """
    def isPlaybackLoop(self) -> bool:
        """
        indicates whether the stream reading will restart after the end of the stream.
        """
    def isPlaying(self) -> bool:
        """
        indicates whether the stream is played or not.
        """
    def setMediaTime(self, fTime: float) -> None:
        """
        sets the new cursor position in the media stream.
        
        After using this method the stream is stopped.
        """
    def setMute(self, bSet: bool) -> None:
        """
        sets the volume to 0 or to its previous value.
        """
    def setPlaybackLoop(self, bSet: bool) -> None:
        """
        sets whether the stream reading should restart at the stream start after the end of the stream.
        """
    def setVolumeDB(self, nDB: int) -> None:
        """
        sets the audio volume in decibel.
        """
    def start(self) -> None:
        """
        starts reading the stream from the current position.
        """
    def stop(self) -> None:
        """
        stops reading the stream and leave the cursor at its current position.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_database_parameter_listener import XDatabaseParameterListener as XDatabaseParameterListener_77e01110

class XDatabaseParameterBroadcaster(XInterface_8f010a43):
    """
    provides the possibility of receiving an event for configuration of parameters.
    
    This interface is usually implemented by components which are to execute a statement, and may need parameter information. For example, the com.sun.star.form.component.DataForm is such a component. When it is bound to a statement which contains parameters, or to a query which is based upon a parametrized statement, it needs values to fill in the parameters with actual values when it is being loaded. One method to gather these values is calling the XDatabaseParameterListener listeners, which can fill them in.

    See Also:
        `API XDatabaseParameterBroadcaster <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XDatabaseParameterBroadcaster.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.form.XDatabaseParameterBroadcaster']

    def addParameterListener(self, aListener: 'XDatabaseParameterListener_77e01110') -> None:
        """
        adds the specified listener, to allow it to fill in necessary parameter values.
        """
    def removeParameterListener(self, aListener: 'XDatabaseParameterListener_77e01110') -> None:
        """
        removes the specified listener.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..util.url import URL as URL_57ad07b9


class DispatchDescriptor(object):
    """
    Struct Class

    describes a feature to be retrieved by a URL that has to be loaded into a specified frame
    
    For a normal dispatch calls all needed parameters are separated. For optimized remote functionality XDispatch.queryDispatches() it's necessary to pack these parameters in a flat structure which can be used in a simple manner.

    See Also:
        `API DispatchDescriptor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1DispatchDescriptor.html>`_
    """
    typeName: Literal['com.sun.star.frame.DispatchDescriptor']

    def __init__(self, FeatureURL: typing.Optional[URL_57ad07b9] = ..., FrameName: typing.Optional[str] = ..., SearchFlags: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            FeatureURL (URL, optional): FeatureURL value.
            FrameName (str, optional): FrameName value.
            SearchFlags (int, optional): SearchFlags value.
        """


    @property
    def FeatureURL(self) -> URL_57ad07b9:
        """
        specifies the URL of the resource/function
        
        Must be a full parsed URL. Use service com.sun.star.util.URLTransformer for that.
        """


    @property
    def FrameName(self) -> str:
        """
        name of the target frame
        
        Special targets (e.g. \"_blank\", \"_self\") or really existing target names can be used.
        """


    @property
    def SearchFlags(self) -> int:
        """
        describes how the target frame is to be searched
        
        This optional parameter is used if FrameName isn't a special target only.
        """





# coding: utf-8
import os
from typing import TYPE_CHECKING

__version__ = "0.4.5"
__version_tmpl__ = "0.2.8"

_IGNORE_IMPORT_ERROR = os.environ.get(
    "ooouno_ignore_import_error", None) in ("True", "true", "yes")

if TYPE_CHECKING == False and _IGNORE_IMPORT_ERROR == False:
    raise ImportError



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui.dialogs
from typing_extensions import Literal


class ExtendedFilePickerElementIds(object):
    """
    Const

    These constants are used to specify extended controls of a FilePicker dialog. A FilePicker service may be initialized so that it has additional controls extending the set of common controls a FilePicker usually supports.
    
    **since**
    
        LibreOffice 6.0

    See Also:
        `API ExtendedFilePickerElementIds <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1ExtendedFilePickerElementIds.html>`_
    """
    CHECKBOX_AUTOEXTENSION: Literal[100]
    CHECKBOX_PASSWORD: Literal[101]
    CHECKBOX_FILTEROPTIONS: Literal[102]
    CHECKBOX_READONLY: Literal[103]
    CHECKBOX_LINK: Literal[104]
    CHECKBOX_PREVIEW: Literal[105]
    PUSHBUTTON_PLAY: Literal[106]
    LISTBOX_VERSION: Literal[107]
    LISTBOX_TEMPLATE: Literal[108]
    LISTBOX_IMAGE_TEMPLATE: Literal[109]
    CHECKBOX_SELECTION: Literal[110]
    LISTBOX_VERSION_LABEL: Literal[207]
    LISTBOX_TEMPLATE_LABEL: Literal[208]
    LISTBOX_IMAGE_TEMPLATE_LABEL: Literal[209]
    LISTBOX_FILTER_SELECTOR: Literal[210]
    CHECKBOX_GPGENCRYPTION: Literal[211]
    LISTBOX_IMAGE_ANCHOR: Literal[212]
    LISTBOX_IMAGE_ANCHOR_LABEL: Literal[213]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from typing_extensions import Literal
import typing
from .x_encryption_protected_source import XEncryptionProtectedSource as XEncryptionProtectedSource_8cdf11a3
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3

class XEncryptionProtectedSource2(XEncryptionProtectedSource_8cdf11a3):
    """
    This interface allows to set a password for an object.
    
    **since**
    
        OOo 3.4

    See Also:
        `API XEncryptionProtectedSource2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XEncryptionProtectedSource2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.embed.XEncryptionProtectedSource2']

    def hasEncryptionData(self) -> bool:
        """
        determine if an encryption data is set for this object.
        """
    def setEncryptionData(self, aEncryptionData: 'typing.Tuple[NamedValue_a37a0af3, ...]') -> None:
        """
        sets an encryption data for the object.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
"""
Const

Values to be passed to XCalendar.getDisplayName().

**since**

    LibreOffice 3.5

See Also:
    `API CalendarDisplayIndex <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1CalendarDisplayIndex.html>`_
"""
AM_PM: Literal[0]
"""
name of an AM/PM value
"""
DAY: Literal[1]
"""
name of a day of week
"""
MONTH: Literal[2]
"""
name of a month
"""
YEAR: Literal[3]
"""
name of a year (if used for a specific calendar)
"""
ERA: Literal[4]
"""
name of an era, like BC/AD
"""
GENITIVE_MONTH: Literal[5]
"""
name of a possessive genitive case month

**since**

    LibreOffice 3.5
"""
PARTITIVE_MONTH: Literal[6]
"""
name of a partitive case month

**since**

    LibreOffice 3.5
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ui
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..awt.point import Point as Point_5fb2085e
from ..awt.x_window import XWindow as XWindow_713b0924
from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
from ..view.x_selection_supplier import XSelectionSupplier as XSelectionSupplier_fed20e15


class ContextMenuExecuteEvent(object):
    """
    Struct Class

    contains all information about the requested context menu.

    See Also:
        `API ContextMenuExecuteEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ui_1_1ContextMenuExecuteEvent.html>`_
    """
    typeName: Literal['com.sun.star.ui.ContextMenuExecuteEvent']

    def __init__(self, SourceWindow: typing.Optional[XWindow_713b0924] = ..., ExecutePosition: typing.Optional[Point_5fb2085e] = ..., ActionTriggerContainer: typing.Optional[XIndexContainer_1c040ebe] = ..., Selection: typing.Optional[XSelectionSupplier_fed20e15] = ...) -> None:
        """
        Constructor

        Arguments:
            SourceWindow (XWindow, optional): SourceWindow value.
            ExecutePosition (Point, optional): ExecutePosition value.
            ActionTriggerContainer (XIndexContainer, optional): ActionTriggerContainer value.
            Selection (XSelectionSupplier, optional): Selection value.
        """


    @property
    def SourceWindow(self) -> XWindow_713b0924:
        """
        contains the window where the context menu has been requested
        """


    @property
    def ExecutePosition(self) -> Point_5fb2085e:
        """
        contains the position the context menu will be executed at.
        """


    @property
    def ActionTriggerContainer(self) -> XIndexContainer_1c040ebe:
        """
        enables the access to the menu content.
        
        The implementing object has to support the service com.sun.star.ui.ActionTriggerContainer;
        """


    @property
    def Selection(self) -> XSelectionSupplier_fed20e15:
        """
        provides the current selection inside the source window.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form
import typing
from .form_control_model import FormControlModel as FormControlModel_e2990d22
from .x_bound_component import XBoundComponent as XBoundComponent_d4830cbf
from .x_load_listener import XLoadListener as XLoadListener_bb200bda
from .x_reset import XReset as XReset_71670917
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class DataAwareControlModel(FormControlModel_e2990d22, XBoundComponent_d4830cbf, XLoadListener_bb200bda, XReset_71670917):
    """
    Service Class

    is an abstract service for specialized FormControlModels which are data aware and thus can be bound to a data source.
    
    The connection between a data-aware control model and a form whose data the control should display is made by parentship relations. The parent of a data-aware control model (see com.sun.star.container.XChild, inherited via the FormControlModel and FormComponent services) has always to be a com.sun.star.form.component.DataForm.
    
    **since**
    
        OOo 3.1

    See Also:
        `API DataAwareControlModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1DataAwareControlModel.html>`_
    """
    @property
    def BoundField(self) -> 'XPropertySet_bc180bfa':
        """
        references to the cursor field to which the control is bound.
        
        Applies only if the form the control model belongs to is loaded and the control is valid bound. The referenced field supports the com.sun.star.sdb.Column service.
        """
    @property
    def DataField(self) -> str:
        """
        specifies the name of the bound database field.
        
        This property makes sense in the context of the control model only. Normally, a control model is a child of a com.sun.star.form.component.DataForm, which is bound to a higher level object such as a table or query - more general, a result set.
        This member here describes the column of this result set which the control should act for.
        
        Not every control model can be bound to every database column. Usually, super services of the DataAwareControlModel restrict the column types they can be used with.
        """
    @property
    def InputRequired(self) -> bool:
        """
        determines whether or not input into this field is required, when it is actually bound to a database field.
        
        If this property is set to FALSE, then the form runtime will not check the control/model for NULL values before submitting data to the database. Usually, if a control model is bound to a database field which cannot be NULL, and the model itself does not have a value, then the database update is prevented, showing an error message to the user. To disable this behavior on a per-control basis, use the InputRequired property.
        
        **since**
        
            OOo 3.1
        """
    @property
    def LabelControl(self) -> 'XPropertySet_bc180bfa':
        """
        references to a control model within the same document which should be used as a label.
        
        Any user interface action which needs to refer to the control is assumed to use this property.
        A very common design method for forms is to group a data aware control with a label control, with the latter describing the content of the former. For instance, you may have a com.sun.star.form.component.TextField, which is bound to the e-mail column of your data source. Then you will probably add a com.sun.star.form.component.FixedText whose label is \"E-Mail\", and associate it with the TextField by setting it as LabelControl.
        Now if you imagine a component offering data search in a form, this component will examine the LabelControl property, find the com.sun.star.form.component.FixedText, examine it's label, and use this label to refer to the com.sun.star.form.component.TextField.
        
        When setting the property, a number of constraints apply:
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.graphic
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef

class GraphicDescriptor(XPropertySet_bc180bfa):
    """
    Service Class

    This service describes all graphic properties that are available via the com.sun.star.beans.XPropertySet interface.
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API GraphicDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicDescriptor.html>`_
    """
    @property
    def Alpha(self) -> bool:
        """
        Indicates that it is a pixel graphic with an alpha channel.
        
        The status of this flag is not always clear if the graphic was not loaded at all, e.g. in case of just querying for the GraphicDescriptor
        """
    @property
    def Animated(self) -> bool:
        """
        Indicates that it is a graphic that consists of several frames that can be played as an animation.
        
        The status of this flag is not always clear if the graphic was not loaded at all, e.g. in case of just querying for the GraphicDescriptor
        """
    @property
    def BitsPerPixel(self) -> int:
        """
        The number of bits per pixel used for the pixel graphic.
        
        This property is not available for vector graphics and may not be available for some kinds of pixel graphics
        """
    @property
    def GraphicType(self) -> int:
        """
        The type of the graphic.
        """
    @property
    def Linked(self) -> bool:
        """
        Indicates that the graphic is an external linked graphic.
        
        **since**
        
            LibreOffice 6.1
        """
    @property
    def MimeType(self) -> str:
        """
        The MimeType of the loaded graphic.
        
        The mime can be the original mime type of the graphic source the graphic container was constructed from or it can be the internal mime type image/x-vclgraphic, in which case the original mime type is not available anymore
        
        Currently, the following mime types are supported for loaded graphics:
        """
    @property
    def OriginURL(self) -> str:
        """
        The URL of the location from where the graphic was loaded from.
        
        **since**
        
            LibreOffice 6.1
        """
    @property
    def Size100thMM(self) -> 'Size_576707ef':
        """
        The Size of the graphic in 100th mm.
        
        This property may not be available in case of pixel graphics or if the logical size can not be determined correctly for some formats without loading the whole graphic
        """
    @property
    def SizePixel(self) -> 'Size_576707ef':
        """
        The Size of the graphic in pixel.
        
        This property may not be available in case of vector graphics or if the pixel size can not be determined correctly for some formats without loading the whole graphic
        """
    @property
    def Transparent(self) -> bool:
        """
        Indicates that it is a transparent graphic.
        
        This property is always TRUE for vector graphics. The status of this flag is not always clear if the graphic was not loaded at all, e.g. in case of just querying for the GraphicDescriptor.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rdf
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .x_node import XNode as XNode_5ee40822
from .x_resource import XResource as XResource_842709e4
from .xuri import XURI as XURI_5682078c


class Statement(object):
    """
    Struct Class

    represents a RDF statement, or triple.
    
    **since**
    
        OOo 3.2

    See Also:
        `API Statement <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rdf_1_1Statement.html>`_
    """
    typeName: Literal['com.sun.star.rdf.Statement']

    def __init__(self, Subject: typing.Optional[XResource_842709e4] = ..., Predicate: typing.Optional[XURI_5682078c] = ..., Object: typing.Optional[XNode_5ee40822] = ..., Graph: typing.Optional[XURI_5682078c] = ...) -> None:
        """
        Constructor

        Arguments:
            Subject (XResource, optional): Subject value.
            Predicate (XURI, optional): Predicate value.
            Object (XNode, optional): Object value.
            Graph (XURI, optional): Graph value.
        """


    @property
    def Subject(self) -> XResource_842709e4:
        """
        the subject of the RDF statement.
        """


    @property
    def Predicate(self) -> XURI_5682078c:
        """
        the predicate of the RDF statement.
        """


    @property
    def Object(self) -> XNode_5ee40822:
        """
        the object of the RDF statement.
        """


    @property
    def Graph(self) -> XURI_5682078c:
        """
        the named graph that contains this statement, or NULL.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.task
from typing_extensions import Literal
import typing
from .x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51
if typing.TYPE_CHECKING:
    from .x_interaction_request import XInteractionRequest as XInteractionRequest_cb20e7c

class XInteractionHandler2(XInteractionHandler_bf80e51):
    """
    An interaction request handler.
    
    This interface extends the interface XInteractionHandler the way that a caller can determine whether an interaction request was actually handled by the interaction handler.
    
    **since**
    
        OOo 3.2

    See Also:
        `API XInteractionHandler2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1task_1_1XInteractionHandler2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.task.XInteractionHandler2']

    def handleInteractionRequest(self, Request: 'XInteractionRequest_cb20e7c') -> bool:
        """
        Handle an interaction request.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from abc import ABC

class XGlobalSheetSettings(ABC):
    """
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API XGlobalSheetSettings <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XGlobalSheetSettings.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XGlobalSheetSettings']

    @property
    def UserLists(self) -> 'typing.Tuple[str, ...]':
        """
        contains the string lists used for sorting and filling.
        
        Each string contains the members of a list, separated by commas.
        """

    @property
    def DoAutoComplete(self) -> bool:
        """
        specifies whether automatic completion of text in a cell is used.
        """

    @property
    def EnterEdit(self) -> bool:
        """
        specifies whether the enter key can be used to start editing a cell.
        """

    @property
    def ExpandReferences(self) -> bool:
        """
        specifies whether formula references are extended when cells are inserted below or to the right of them.
        """

    @property
    def ExtendFormat(self) -> bool:
        """
        specifies whether cell formatting is extended when entering data.
        """

    @property
    def LinkUpdateMode(self) -> int:
        """
        specifies the update mode for external linked data.
        
        0 = always
        
        1 = never
        
        2 = on demand
        """

    @property
    def MarkHeader(self) -> bool:
        """
        specifies whether the current selection is highlighted in column and row headers.
        """

    @property
    def Metric(self) -> int:
        """
        contains the metric for all spreadsheet documents.
        """

    @property
    def MoveDirection(self) -> int:
        """
        contains the direction the cursor moves after entering cells.
        """

    @property
    def MoveSelection(self) -> bool:
        """
        specifies whether the cursor is moved after entering into cells.
        """

    @property
    def PrintAllSheets(self) -> bool:
        """
        specifies whether all sheets or only selected sheets are printed.
        """

    @property
    def PrintEmptyPages(self) -> bool:
        """
        specifies whether empty pages are printed.
        """

    @property
    def RangeFinder(self) -> bool:
        """
        specifies whether ranges are highlighted on the sheet when editing a formula.
        """

    @property
    def ReplaceCellsWarning(self) -> bool:
        """
        specifies whether a warning is shown before replacing cells (i.e.
        
        when pasting from clipboard).
        """

    @property
    def Scale(self) -> int:
        """
        contains the default scale for new spreadsheet documents (in percent).
        
        There are several special values:
        
        -1 = Optimal width
        
        -2 = Show whole page
        
        -3 = Page width
        """

    @property
    def StatusBarFunction(self) -> int:
        """
        contains the function that is displayed in the status bar.
        """

    @property
    def UsePrinterMetrics(self) -> bool:
        """
        specifies whether printer metrics are used for display.
        """

    @property
    def UseTabCol(self) -> bool:
        """
        specifies whether the enter key moves the cursor to the column it was in before using the tab key to change columns.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
"""
Const


See Also:
    `API ConditionFormatOperator <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html>`_
"""
EQUAL: Literal[0]
LESS: Literal[1]
GREATER: Literal[2]
LESS_EQUAL: Literal[3]
GREATER_EQUAL: Literal[4]
NOT_EQUAL: Literal[5]
BETWEEN: Literal[6]
NOT_BETWEEN: Literal[7]
DUPLICATE: Literal[8]
UNIQUE: Literal[9]
TOP_N_ELEMENTS: Literal[10]
BOTTOM_N_ELEMENTS: Literal[11]
TOP_N_PERCENT: Literal[12]
BOTTOM_N_PERCENT: Literal[13]
ABOVE_AVERAGE: Literal[14]
BELOW_AVERAGE: Literal[15]
ABOVE_EQUAL_AVERAGE: Literal[16]
BELOW_EQUAL_AVERAGE: Literal[17]
ERROR: Literal[18]
NO_ERROR: Literal[19]
BEGINS_WITH: Literal[20]
ENDS_WITH: Literal[21]
CONTAINS: Literal[22]
NOT_CONTAINS: Literal[23]
EXPRESSION: Literal[24]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_named import XNamed as XNamed_a6520b08
from ..util.x_refreshable import XRefreshable as XRefreshable_b0d60b81

class SheetLink(XPropertySet_bc180bfa, XNamed_a6520b08, XRefreshable_b0d60b81):
    """
    Service Class

    represents a sheet link.
    
    A sheet link contains the source data of linked sheets, i.e. the URL and sheet name of the external document.
    
    To create a linked sheet, the sheet which will be used as linked sheet has to exist already. The method XSheetLinkable.link() creates a SheetLink object in the document's SheetLinks collection and links the sheet to the specified external sheet.

    See Also:
        `API SheetLink <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SheetLink.html>`_
    """
    @property
    def Filter(self) -> str:
        """
        specifies the name of the filter needed to load the source document.
        """
    @property
    def FilterOptions(self) -> str:
        """
        specifies the filter options needed to load the source document.
        """
    @property
    def Url(self) -> str:
        """
        specifies the URL of the source document.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.frame.app_dispatch_provider import AppDispatchProvider as AppDispatchProvider
from .._pyi.frame.auto_recovery import AutoRecovery as AutoRecovery
from .._pyi.frame.bibliography import Bibliography as Bibliography
from .._pyi.frame.border_widths import BorderWidths as BorderWidths
from .._pyi.frame.components import Components as Components
from .._pyi.frame.content_handler import ContentHandler as ContentHandler
from .._pyi.frame.content_handler_factory import ContentHandlerFactory as ContentHandlerFactory
from .._pyi.frame.control_command import ControlCommand as ControlCommand
from .._pyi.frame.control_event import ControlEvent as ControlEvent
from .._pyi.frame.controller import Controller as Controller
from .._pyi.frame.desktop import Desktop as Desktop
from .._pyi.frame.desktop_task import DesktopTask as DesktopTask
from .._pyi.frame.desktop_tasks import DesktopTasks as DesktopTasks
from .._pyi.frame.dispatch_descriptor import DispatchDescriptor as DispatchDescriptor
from .._pyi.frame.dispatch_helper import DispatchHelper as DispatchHelper
from .._pyi.frame.dispatch_information import DispatchInformation as DispatchInformation
from .._pyi.frame.dispatch_provider import DispatchProvider as DispatchProvider
from .._pyi.frame.dispatch_recorder import DispatchRecorder as DispatchRecorder
from .._pyi.frame.dispatch_recorder_supplier import DispatchRecorderSupplier as DispatchRecorderSupplier
from .._pyi.frame.dispatch_result_event import DispatchResultEvent as DispatchResultEvent
from .._pyi.frame.dispatch_statement import DispatchStatement as DispatchStatement
from .._pyi.frame.document_templates import DocumentTemplates as DocumentTemplates
from .._pyi.frame.double_initialization_exception import DoubleInitializationException as DoubleInitializationException
from .._pyi.frame.feature_state_event import FeatureStateEvent as FeatureStateEvent
from .._pyi.frame.frame import Frame as Frame
from .._pyi.frame.frame_action_event import FrameActionEvent as FrameActionEvent
from .._pyi.frame.frame_control import FrameControl as FrameControl
from .._pyi.frame.frame_loader import FrameLoader as FrameLoader
from .._pyi.frame.frame_loader_factory import FrameLoaderFactory as FrameLoaderFactory
from .._pyi.frame.frames_container import FramesContainer as FramesContainer
from .._pyi.frame.global_event_broadcaster import GlobalEventBroadcaster as GlobalEventBroadcaster
from .._pyi.frame.illegal_argument_io_exception import IllegalArgumentIOException as IllegalArgumentIOException
from .._pyi.frame.layout_manager import LayoutManager as LayoutManager
from .._pyi.frame.media_type_detection_helper import MediaTypeDetectionHelper as MediaTypeDetectionHelper
from .._pyi.frame.module_manager import ModuleManager as ModuleManager
from .._pyi.frame.office_frame_loader import OfficeFrameLoader as OfficeFrameLoader
from .._pyi.frame.popup_menu_controller import PopupMenuController as PopupMenuController
from .._pyi.frame.popup_menu_controller_factory import PopupMenuControllerFactory as PopupMenuControllerFactory
from .._pyi.frame.protocol_handler import ProtocolHandler as ProtocolHandler
from .._pyi.frame.session_listener import SessionListener as SessionListener
from .._pyi.frame.session_manager import SessionManager as SessionManager
from .._pyi.frame.settings import Settings as Settings
from .._pyi.frame.start_module import StartModule as StartModule
from .._pyi.frame.statusbar_controller import StatusbarController as StatusbarController
from .._pyi.frame.statusbar_controller_factory import StatusbarControllerFactory as StatusbarControllerFactory
from .._pyi.frame.synchronous_frame_loader import SynchronousFrameLoader as SynchronousFrameLoader
from .._pyi.frame.task import Task as Task
from .._pyi.frame.task_creator import TaskCreator as TaskCreator
from .._pyi.frame.template_access import TemplateAccess as TemplateAccess
from .._pyi.frame.termination_veto_exception import TerminationVetoException as TerminationVetoException
from .._pyi.frame.title_changed_event import TitleChangedEvent as TitleChangedEvent
from .._pyi.frame.toolbar_controller import ToolbarController as ToolbarController
from .._pyi.frame.toolbar_controller_factory import ToolbarControllerFactory as ToolbarControllerFactory
from .._pyi.frame.transient_documents_document_content_factory import TransientDocumentsDocumentContentFactory as TransientDocumentsDocumentContentFactory
from .._pyi.frame.ui_command_description import UICommandDescription as UICommandDescription
from .._pyi.frame.unknown_module_exception import UnknownModuleException as UnknownModuleException
from .._pyi.frame.x_app_dispatch_provider import XAppDispatchProvider as XAppDispatchProvider
from .._pyi.frame.x_border_resize_listener import XBorderResizeListener as XBorderResizeListener
from .._pyi.frame.x_browse_history_registry import XBrowseHistoryRegistry as XBrowseHistoryRegistry
from .._pyi.frame.x_component_loader import XComponentLoader as XComponentLoader
from .._pyi.frame.x_component_registry import XComponentRegistry as XComponentRegistry
from .._pyi.frame.x_config_manager import XConfigManager as XConfigManager
from .._pyi.frame.x_control_notification_listener import XControlNotificationListener as XControlNotificationListener
from .._pyi.frame.x_controller import XController as XController
from .._pyi.frame.x_controller2 import XController2 as XController2
from .._pyi.frame.x_controller_border import XControllerBorder as XControllerBorder
from .._pyi.frame.x_desktop import XDesktop as XDesktop
from .._pyi.frame.x_desktop2 import XDesktop2 as XDesktop2
from .._pyi.frame.x_desktop_task import XDesktopTask as XDesktopTask
from .._pyi.frame.x_dispatch import XDispatch as XDispatch
from .._pyi.frame.x_dispatch_helper import XDispatchHelper as XDispatchHelper
from .._pyi.frame.x_dispatch_information_provider import XDispatchInformationProvider as XDispatchInformationProvider
from .._pyi.frame.x_dispatch_provider import XDispatchProvider as XDispatchProvider
from .._pyi.frame.x_dispatch_provider_interception import XDispatchProviderInterception as XDispatchProviderInterception
from .._pyi.frame.x_dispatch_provider_interceptor import XDispatchProviderInterceptor as XDispatchProviderInterceptor
from .._pyi.frame.x_dispatch_recorder import XDispatchRecorder as XDispatchRecorder
from .._pyi.frame.x_dispatch_recorder_supplier import XDispatchRecorderSupplier as XDispatchRecorderSupplier
from .._pyi.frame.x_dispatch_result_listener import XDispatchResultListener as XDispatchResultListener
from .._pyi.frame.x_document_templates import XDocumentTemplates as XDocumentTemplates
from .._pyi.frame.x_extended_filter_detection import XExtendedFilterDetection as XExtendedFilterDetection
from .._pyi.frame.x_filter_detect import XFilterDetect as XFilterDetect
from .._pyi.frame.x_frame import XFrame as XFrame
from .._pyi.frame.x_frame2 import XFrame2 as XFrame2
from .._pyi.frame.x_frame_action_listener import XFrameActionListener as XFrameActionListener
from .._pyi.frame.x_frame_loader import XFrameLoader as XFrameLoader
from .._pyi.frame.x_frame_loader_query import XFrameLoaderQuery as XFrameLoaderQuery
from .._pyi.frame.x_frame_set_model import XFrameSetModel as XFrameSetModel
from .._pyi.frame.x_frames import XFrames as XFrames
from .._pyi.frame.x_frames_supplier import XFramesSupplier as XFramesSupplier
from .._pyi.frame.x_global_event_broadcaster import XGlobalEventBroadcaster as XGlobalEventBroadcaster
from .._pyi.frame.x_infobar_provider import XInfobarProvider as XInfobarProvider
from .._pyi.frame.x_interceptor_info import XInterceptorInfo as XInterceptorInfo
from .._pyi.frame.x_layout_manager import XLayoutManager as XLayoutManager
from .._pyi.frame.x_layout_manager2 import XLayoutManager2 as XLayoutManager2
from .._pyi.frame.x_layout_manager_event_broadcaster import XLayoutManagerEventBroadcaster as XLayoutManagerEventBroadcaster
from .._pyi.frame.x_layout_manager_listener import XLayoutManagerListener as XLayoutManagerListener
from .._pyi.frame.x_load_event_listener import XLoadEventListener as XLoadEventListener
from .._pyi.frame.x_loadable import XLoadable as XLoadable
from .._pyi.frame.x_loader_factory import XLoaderFactory as XLoaderFactory
from .._pyi.frame.x_menu_bar_acceptor import XMenuBarAcceptor as XMenuBarAcceptor
from .._pyi.frame.x_menu_bar_merging_acceptor import XMenuBarMergingAcceptor as XMenuBarMergingAcceptor
from .._pyi.frame.x_model import XModel as XModel
from .._pyi.frame.x_model2 import XModel2 as XModel2
from .._pyi.frame.x_model3 import XModel3 as XModel3
from .._pyi.frame.x_module import XModule as XModule
from .._pyi.frame.x_module_manager import XModuleManager as XModuleManager
from .._pyi.frame.x_module_manager2 import XModuleManager2 as XModuleManager2
from .._pyi.frame.x_notifying_dispatch import XNotifyingDispatch as XNotifyingDispatch
from .._pyi.frame.x_popup_menu_controller import XPopupMenuController as XPopupMenuController
from .._pyi.frame.x_recordable_dispatch import XRecordableDispatch as XRecordableDispatch
from .._pyi.frame.x_session_manager_client import XSessionManagerClient as XSessionManagerClient
from .._pyi.frame.x_session_manager_listener import XSessionManagerListener as XSessionManagerListener
from .._pyi.frame.x_session_manager_listener2 import XSessionManagerListener2 as XSessionManagerListener2
from .._pyi.frame.x_status_listener import XStatusListener as XStatusListener
from .._pyi.frame.x_statusbar_controller import XStatusbarController as XStatusbarController
from .._pyi.frame.x_storable import XStorable as XStorable
from .._pyi.frame.x_storable2 import XStorable2 as XStorable2
from .._pyi.frame.x_sub_toolbar_controller import XSubToolbarController as XSubToolbarController
from .._pyi.frame.x_synchronous_dispatch import XSynchronousDispatch as XSynchronousDispatch
from .._pyi.frame.x_synchronous_frame_loader import XSynchronousFrameLoader as XSynchronousFrameLoader
from .._pyi.frame.x_task import XTask as XTask
from .._pyi.frame.x_tasks_supplier import XTasksSupplier as XTasksSupplier
from .._pyi.frame.x_terminate_listener import XTerminateListener as XTerminateListener
from .._pyi.frame.x_terminate_listener2 import XTerminateListener2 as XTerminateListener2
from .._pyi.frame.x_title import XTitle as XTitle
from .._pyi.frame.x_title_change_broadcaster import XTitleChangeBroadcaster as XTitleChangeBroadcaster
from .._pyi.frame.x_title_change_listener import XTitleChangeListener as XTitleChangeListener
from .._pyi.frame.x_toolbar_controller import XToolbarController as XToolbarController
from .._pyi.frame.x_toolbar_controller_listener import XToolbarControllerListener as XToolbarControllerListener
from .._pyi.frame.x_transient_documents_document_content_factory import XTransientDocumentsDocumentContentFactory as XTransientDocumentsDocumentContentFactory
from .._pyi.frame.x_transient_documents_document_content_identifier_factory import XTransientDocumentsDocumentContentIdentifierFactory as XTransientDocumentsDocumentContentIdentifierFactory
from .._pyi.frame.xui_controller_factory import XUIControllerFactory as XUIControllerFactory
from .._pyi.frame.xui_controller_registration import XUIControllerRegistration as XUIControllerRegistration
from .._pyi.frame.x_untitled_numbers import XUntitledNumbers as XUntitledNumbers
from .._pyi.frame.x_url_list import XUrlList as XUrlList
from .._pyi.frame.x_window_arranger import XWindowArranger as XWindowArranger
from .._pyi.frame.the_auto_recovery import theAutoRecovery as theAutoRecovery
from .._pyi.frame.the_desktop import theDesktop as theDesktop
from .._pyi.frame.the_global_event_broadcaster import theGlobalEventBroadcaster as theGlobalEventBroadcaster
from .._pyi.frame.the_popup_menu_controller_factory import thePopupMenuControllerFactory as thePopupMenuControllerFactory
from .._pyi.frame.the_statusbar_controller_factory import theStatusbarControllerFactory as theStatusbarControllerFactory
from .._pyi.frame.the_toolbar_controller_factory import theToolbarControllerFactory as theToolbarControllerFactory
from .._pyi.frame.the_ui_command_description import theUICommandDescription as theUICommandDescription



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal
from .x_text_cursor import XTextCursor as XTextCursor_a60c0b48

class XSentenceCursor(XTextCursor_a60c0b48):
    """
    makes it possible to perform cursor movements through sentences.

    See Also:
        `API XSentenceCursor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XSentenceCursor.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.text.XSentenceCursor']

    def gotoEndOfSentence(self, Expand: bool) -> bool:
        """
        moves the cursor to the end of the current sentence.
        """
    def gotoNextSentence(self, Expand: bool) -> bool:
        """
        moves the cursor to the start of the next sentence.
        """
    def gotoPreviousSentence(self, Expand: bool) -> bool:
        """
        moves the cursor to the start of the previous sentence.
        """
    def gotoStartOfSentence(self, Expand: bool) -> bool:
        """
        moves the cursor to the start of the current sentence.
        """
    def isEndOfSentence(self) -> bool:
        """
        determines if the cursor is positioned at the end of a sentence.
        """
    def isStartOfSentence(self) -> bool:
        """
        determines if the cursor is positioned at the start of a sentence.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XPossibleHyphens(XInterface_8f010a43):
    """
    Gives information about a word's possible hyphenation points.
    
    Example: In German pre-spelling-reform you may have the following: getWord: Dampfschiffahrt getPossibleHyphens: Dampf=schiff=fahrt getOrigHyphensPositions: 4, 9 That is \"Dampfschiffahrt\" can be hyphenated after the \"pf\" (4) and between the double \"ff\" (9). And if you are going to hyphenate it at position 9 you will get an additional \"f\" before the hyphen character.

    See Also:
        `API XPossibleHyphens <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XPossibleHyphens.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.linguistic2.XPossibleHyphens']

    def getHyphenationPositions(self) -> 'typing.Tuple[int, ...]':
        """
        """
    def getLocale(self) -> 'Locale_70d308fa':
        """
        """
    def getPossibleHyphens(self) -> str:
        """
        """
    def getWord(self) -> str:
        """
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.style
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .tab_align import TabAlign as TabAlign_8fc90a3b


class TabStop(object):
    """
    Struct Class

    This structure is used to specify a single tabulator stop.

    See Also:
        `API TabStop <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1style_1_1TabStop.html>`_
    """
    typeName: Literal['com.sun.star.style.TabStop']

    def __init__(self, Position: typing.Optional[int] = ..., Alignment: typing.Optional[TabAlign_8fc90a3b] = ..., DecimalChar: typing.Optional[str] = ..., FillChar: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Position (int, optional): Position value.
            Alignment (TabAlign, optional): Alignment value.
            DecimalChar (str, optional): DecimalChar value.
            FillChar (str, optional): FillChar value.
        """


    @property
    def Position(self) -> int:
        """
        This field specifies the position of the tabulator in relation to the left border.
        """


    @property
    def Alignment(self) -> TabAlign_8fc90a3b:
        """
        This field specifies the alignment of the text range before the tabulator.
        """


    @property
    def DecimalChar(self) -> str:
        """
        This field specifies which delimiter is used for the decimal.
        """


    @property
    def FillChar(self) -> str:
        """
        This field specifies the character that is used to fill up the space between the text in the text range and the tabulators.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from .border_widths import BorderWidths as BorderWidths_bb920be4
    from .x_border_resize_listener import XBorderResizeListener as XBorderResizeListener_37520f81

class XControllerBorder(XInterface_8f010a43):
    """
    allows to retrieve information about controller's border.

    See Also:
        `API XControllerBorder <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XControllerBorder.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XControllerBorder']

    def addBorderResizeListener(self, xListener: 'XBorderResizeListener_37520f81') -> None:
        """
        adds the specified listener to receive events about controller's border resizing.
        """
    def getBorder(self) -> 'BorderWidths_bb920be4':
        """
        allows to get current border sizes of the document.
        """
    def queryBorderedArea(self, aPreliminaryRectangle: 'Rectangle_84b109e9') -> 'Rectangle_84b109e9':
        """
        allows to get suggestion for resizing of object area surrounded by the border.
        
        If the view is going to be resized/moved this method can be used to get suggested object area. Pixels are used as units.
        """
    def removeBorderResizeListener(self, xListener: 'XBorderResizeListener_37520f81') -> None:
        """
        removes the specified listener.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class Date(object):
    """
    Struct Class

    represents a date value.
    
    The time zone is unknown.

    See Also:
        `API Date <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1Date.html>`_
    """
    typeName: Literal['com.sun.star.util.Date']

    def __init__(self, Day: typing.Optional[int] = ..., Month: typing.Optional[int] = ..., Year: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Day (int, optional): Day value.
            Month (int, optional): Month value.
            Year (int, optional): Year value.
        """


    @property
    def Day(self) -> int:
        """
        contains the day of month (1-31 or 0 for a void date).
        """


    @property
    def Month(self) -> int:
        """
        contains the month of year (1-12 or 0 for a void date).
        """


    @property
    def Year(self) -> int:
        """
        contains the year.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class DDEItemInfo(object):
    """
    Struct Class

    describes an item of a DDE connection.
    
    A DDE connection consists of the DDE service name, the DDE topic and a list of DDE items which may contain cached result sets.
    
    **since**
    
        OOo 3.1

    See Also:
        `API DDEItemInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1DDEItemInfo.html>`_
    """
    typeName: Literal['com.sun.star.sheet.DDEItemInfo']

    def __init__(self, Results: typing.Optional[typing.Tuple[typing.Tuple[object, ...], ...]] = ..., Item: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Results (typing.Tuple[typing.Tuple[object, ...], ...], optional): Results value.
            Item (str, optional): Item value.
        """


    @property
    def Results(self) -> typing.Tuple[typing.Tuple[object, ...], ...]:
        """
        The results of the item cached from the last update of the DDE link if available.
        
        This sequence may be empty.
        """


    @property
    def Item(self) -> str:
        """
        The name of the DDE item.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..io.x_output_stream import XOutputStream as XOutputStream_a4e00b35
    from ..io.x_stream import XStream as XStream_678908a4
    from ..task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51
    from ..util.date_time import DateTime as DateTime_84de09d3

class XSimpleFileAccess(XInterface_8f010a43):
    """
    This is the basic interface to read data from a stream.

    See Also:
        `API XSimpleFileAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XSimpleFileAccess.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XSimpleFileAccess']

    def copy(self, SourceURL: str, DestURL: str) -> None:
        """
        Copies a file.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def createFolder(self, NewFolderURL: str) -> None:
        """
        Creates a new Folder.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def exists(self, FileURL: str) -> bool:
        """
        Checks if a file exists.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def getContentType(self, FileURL: str) -> str:
        """
        Returns the content type of a file.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def getDateTimeModified(self, FileURL: str) -> 'DateTime_84de09d3':
        """
        Returns the last modified date for the file.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def getFolderContents(self, FolderURL: str, bIncludeFolders: bool) -> 'typing.Tuple[str, ...]':
        """
        Returns the contents of a folder.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def getSize(self, FileURL: str) -> int:
        """
        Returns the size of a file.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def isFolder(self, FileURL: str) -> bool:
        """
        Checks if a URL represents a folder.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def isReadOnly(self, FileURL: str) -> bool:
        """
        Checks if a file is \"read only\".

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def kill(self, FileURL: str) -> None:
        """
        Removes a file.
        
        If the URL represents a folder, the folder will be removed, even if it's not empty.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def move(self, SourceURL: str, DestURL: str) -> None:
        """
        Moves a file.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def openFileRead(self, FileURL: str) -> 'XInputStream_98d40ab4':
        """
        Opens file to read.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def openFileReadWrite(self, FileURL: str) -> 'XStream_678908a4':
        """
        Opens file to read and write.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def openFileWrite(self, FileURL: str) -> 'XOutputStream_a4e00b35':
        """
        Opens file to write.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def setInteractionHandler(self, Handler: 'XInteractionHandler_bf80e51') -> None:
        """
        Sets an interaction handler to be used for further operations.
        
        A default interaction handler is available as service com.sun.star.task.InteractionHandler. The documentation of this service also contains further information about the interaction handler concept.
        """
    def setReadOnly(self, FileURL: str, bReadOnly: bool) -> None:
        """
        Sets the \"read only\" of a file according to the boolean parameter, if the actual process has the right to do so.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
import typing
from ..beans.x_tolerant_multi_property_set import XTolerantMultiPropertySet as XTolerantMultiPropertySet_7bd4114e
from ..chart.x_chart_data_array import XChartDataArray as XChartDataArray_df4c0cdd
from .sheet_ranges_query import SheetRangesQuery as SheetRangesQuery_efbe0d90
from .x_array_formula_range import XArrayFormulaRange as XArrayFormulaRange_b750e3b
from .x_cell_format_ranges_supplier import XCellFormatRangesSupplier as XCellFormatRangesSupplier_786d1116
from .x_cell_range_addressable import XCellRangeAddressable as XCellRangeAddressable_35260f40
from .x_cell_range_data import XCellRangeData as XCellRangeData_d2e70c60
from .x_cell_range_formula import XCellRangeFormula as XCellRangeFormula_fb270dbc
from .x_cell_series import XCellSeries as XCellSeries_af5c0b64
from .x_multiple_operation import XMultipleOperation as XMultipleOperation_d460e76
from .x_sheet_cell_range import XSheetCellRange as XSheetCellRange_e09d0cdf
from .x_sheet_filterable_ex import XSheetFilterableEx as XSheetFilterableEx_ad60e29
from .x_sheet_operation import XSheetOperation as XSheetOperation_e1f50d23
from .x_sub_total_calculatable import XSubTotalCalculatable as XSubTotalCalculatable_37b30f64
from .x_unique_cell_format_ranges_supplier import XUniqueCellFormatRangesSupplier as XUniqueCellFormatRangesSupplier_e8d5138d
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian_6d8a10df
from ..style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex_90ca11cb
from ..style.paragraph_properties import ParagraphProperties as ParagraphProperties_1e240efc
from ..table.cell_range import CellRange as CellRange_98770a7d
from ..table.x_auto_formattable import XAutoFormattable as XAutoFormattable_ee660d72
from ..table.x_column_row_range import XColumnRowRange as XColumnRowRange_e0e70cfb
from ..util.x_importable import XImportable as XImportable_a5c50b2d
from ..util.x_indent import XIndent as XIndent_7b290980
from ..util.x_mergeable import XMergeable as XMergeable_99dd0aa2
from ..util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0
from ..util.x_replaceable import XReplaceable as XReplaceable_b0750b6e
from ..util.x_sortable import XSortable as XSortable_8ff20a5a
if typing.TYPE_CHECKING:
    from ..awt.point import Point as Point_5fb2085e
    from ..awt.size import Size as Size_576707ef
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from .x_sheet_conditional_entries import XSheetConditionalEntries as XSheetConditionalEntries_694810c0

class SheetCellRange(SheetRangesQuery_efbe0d90, CharacterProperties_1d4f0ef3, CharacterPropertiesAsian_6d8a10df, CharacterPropertiesComplex_90ca11cb, ParagraphProperties_1e240efc, CellRange_98770a7d, XTolerantMultiPropertySet_7bd4114e, XChartDataArray_df4c0cdd, XArrayFormulaRange_b750e3b, XCellFormatRangesSupplier_786d1116, XCellRangeAddressable_35260f40, XCellRangeData_d2e70c60, XCellRangeFormula_fb270dbc, XCellSeries_af5c0b64, XMultipleOperation_d460e76, XSheetCellRange_e09d0cdf, XSheetFilterableEx_ad60e29, XSheetOperation_e1f50d23, XSubTotalCalculatable_37b30f64, XUniqueCellFormatRangesSupplier_e8d5138d, XAutoFormattable_ee660d72, XColumnRowRange_e0e70cfb, XImportable_a5c50b2d, XIndent_7b290980, XMergeable_99dd0aa2, XModifyBroadcaster_fd990df0, XReplaceable_b0750b6e, XSortable_8ff20a5a):
    """
    Service Class

    represents a rectangular range of cells in a spreadsheet document.
    
    This service is an extension of the CellRange service for use in spreadsheet documents.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API SheetCellRange <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellRange.html>`_
    """
    @property
    def AbsoluteName(self) -> str:
        """
        Returns the absolute address of the range as string, e.g.
        
        \"$Sheet1.$B$2:$D$5\".
        """
    @property
    def ConditionalFormat(self) -> 'XSheetConditionalEntries_694810c0':
        """
        contains the conditional formatting settings for this cell.
        
        After a conditional format has been changed it has to be reinserted into the property set.
        """
    @property
    def ConditionalFormatLocal(self) -> 'XSheetConditionalEntries_694810c0':
        """
        contains the conditional formatting settings for this cell, using localized formulas.
        
        After a conditional format has been changed it has to be reinserted into the property set.
        """
    @property
    def Position(self) -> 'Point_5fb2085e':
        """
        contains the position of the top left cell of this range in the sheet (in 1/100 mm).
        
        This property contains the absolute position in the whole sheet, not the position in the visible area.
        """
    @property
    def Size(self) -> 'Size_576707ef':
        """
        contains the size of this range (in 1/100 mm).
        """
    @property
    def Validation(self) -> 'XPropertySet_bc180bfa':
        """
        contains the data validation settings for this cell.
        
        After the data validation settings have been changed the validation has to be reinserted into the property set.
        """
    @property
    def ValidationLocal(self) -> 'XPropertySet_bc180bfa':
        """
        contains the data validation settings for this cell, using localized formulas.
        
        After the data validation settings have been changed the validation has to be reinserted into the property set.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal
"""
Const

These values define the reference position of relative orientations.

**since**

    LibreOffice 7.0

See Also:
    `API RelOrientation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html>`_
"""
FRAME: Literal[0]
"""
paragraph, including margins
"""
PRINT_AREA: Literal[1]
"""
paragraph, without margins
"""
CHAR: Literal[2]
"""
at a character
"""
PAGE_LEFT: Literal[3]
"""
inside the left page margin
"""
PAGE_RIGHT: Literal[4]
"""
inside the right page margin
"""
FRAME_LEFT: Literal[5]
"""
inside the left paragraph margin
"""
FRAME_RIGHT: Literal[6]
"""
inside the right paragraph margin
"""
PAGE_FRAME: Literal[7]
"""
page includes margins for page-anchored frames identical with RelOrientation.FRAME
"""
PAGE_PRINT_AREA: Literal[8]
"""
page without borders (for page anchored frames identical with RelOrientation.PRINT_AREA).
"""
TEXT_LINE: Literal[9]
"""
at the top of the text line, only sensible for vertical orientation.

**since**

    OOo 2.0
"""
PAGE_PRINT_AREA_BOTTOM: Literal[10]
"""
Bottom page border (page area below PAGE_PRINT_AREA).

**since**

    LibreOffice 7.0
"""
PAGE_PRINT_AREA_TOP: Literal[11]
"""
Top page border (page area above PAGE_PRINT_AREA).

**since**

    LibreOffice 7.1
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from typing_extensions import Literal


class EntryInitModes(object):
    """
    Const

    This constant set contains possible modes to initialize object persistence.

    See Also:
        `API EntryInitModes <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1embed_1_1EntryInitModes.html>`_
    """
    DEFAULT_INIT: Literal[0]
    """
    In case object persistence is created based on existing entry, the object should be initialized from this entry.
    
    Otherwise the object should be initialized as a new one.
    """
    TRUNCATE_INIT: Literal[1]
    """
    The object should be initialized as a new empty one.
    """
    NO_INIT: Literal[2]
    """
    The object should be initialized as a new one only in case it still was not initialized.
    
    If the object initialized already do not reinitialize it.
    """
    MEDIA_DESCRIPTOR_INIT: Literal[3]
    """
    The object should be initialized using additional arguments from provided com.sun.star.document.MediaDescriptor.
    """
    URL_LINK_INIT: Literal[4]
    """
    The object should be initialized as a link using URL provided in additional arguments.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class FormatElement(object):
    """
    Struct Class

    One number format code and its attributes, returned in a sequence by XLocaleData.getAllFormats().
    
    Contains raw data defined in the XML locale data files.

    See Also:
        `API FormatElement <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1FormatElement.html>`_
    """
    typeName: Literal['com.sun.star.i18n.FormatElement']

    def __init__(self, formatCode: typing.Optional[str] = ..., formatName: typing.Optional[str] = ..., formatKey: typing.Optional[str] = ..., formatType: typing.Optional[str] = ..., formatUsage: typing.Optional[str] = ..., formatIndex: typing.Optional[int] = ..., isDefault: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            formatCode (str, optional): formatCode value.
            formatName (str, optional): formatName value.
            formatKey (str, optional): formatKey value.
            formatType (str, optional): formatType value.
            formatUsage (str, optional): formatUsage value.
            formatIndex (int, optional): formatIndex value.
            isDefault (bool, optional): isDefault value.
        """


    @property
    def formatCode(self) -> str:
        """
        The format code, for example, \"YYYY-MM-DD\".
        """


    @property
    def formatName(self) -> str:
        """
        A name or description that is displayed in the number formatter dialog.
        """


    @property
    def formatKey(self) -> str:
        """
        A unique (within one locale) identifier.
        """


    @property
    def formatType(self) -> str:
        """
        Type may be one of \"short\", \"medium\", \"long\".
        """


    @property
    def formatUsage(self) -> str:
        """
        Usage category, for example, \"DATE\" or \"FIXED_NUMBER\", corresponding with KNumberFormatUsage values.
        """


    @property
    def formatIndex(self) -> int:
        """
        The index used by the number formatter, predefined values corresponding with NumberFormatIndex values.
        """


    @property
    def isDefault(self) -> bool:
        """
        If a format code is the default code of a formatType group.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
"""
Const

determines whether a procedure returns a result or not.

See Also:
    `API ProcedureResult <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdbc_1_1ProcedureResult.html>`_
"""
UNKNOWN: Literal[0]
"""
A possible value for column PROCEDURE_TYPE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedures().

Indicates that it is not known whether the procedure returns a result.
"""
NONE: Literal[1]
"""
A possible value for column PROCEDURE_TYPE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedures().

Indicates that the procedure does not return a result.
"""
RETURN: Literal[2]
"""
A possible value for column PROCEDURE_TYPE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedures().

Indicates that the procedure returns a result.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal


class CalendarDisplayCode(object):
    """
    Const

    Constants to use with XExtendedCalendar.getDisplayString().
    
    The examples given are for an English Gregorian calendar, note that other calendars or locales may return completely different strings, for example not a four digit year but a CJK name instead.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API CalendarDisplayCode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1CalendarDisplayCode.html>`_
    """
    SHORT_DAY: Literal[1]
    """
    Day of month, one or two digits, no leading zero.
    """
    LONG_DAY: Literal[2]
    """
    Day of month, two digits, with leading zero.
    """
    SHORT_DAY_NAME: Literal[3]
    """
    Day of week, abbreviated name.
    """
    LONG_DAY_NAME: Literal[4]
    """
    Day of week, full name.
    """
    SHORT_MONTH: Literal[5]
    """
    Month of year, one or two digits, no leading zero.
    """
    LONG_MONTH: Literal[6]
    """
    Month of year, with leading zero.
    """
    SHORT_MONTH_NAME: Literal[7]
    """
    Abbreviated month name.
    """
    LONG_MONTH_NAME: Literal[8]
    """
    Full month name.
    """
    SHORT_YEAR: Literal[9]
    """
    Year, two digits.
    """
    LONG_YEAR: Literal[10]
    """
    Year, four digits.
    """
    SHORT_ERA: Literal[11]
    """
    Abbreviated era name, for example, BC or AD.
    """
    LONG_ERA: Literal[12]
    """
    Full era name, for example, \"Before Christ\" or \"Anno Dominus\".
    """
    SHORT_YEAR_AND_ERA: Literal[13]
    """
    Combined short year and era, order depends on locale/calendar.
    """
    LONG_YEAR_AND_ERA: Literal[14]
    """
    Combined full year and era, order depends on locale/calendar.
    """
    SHORT_QUARTER: Literal[15]
    """
    Short quarter, for example, \"Q1\".
    """
    LONG_QUARTER: Literal[16]
    """
    Long quarter, for example, \"1st quarter\".
    """
    SHORT_GENITIVE_MONTH_NAME: Literal[17]
    """
    Abbreviated possessive genitive case month name.
    
    **since**
    
        LibreOffice 3.5
    """
    LONG_GENITIVE_MONTH_NAME: Literal[18]
    """
    Full possessive genitive case month name.
    
    **since**
    
        LibreOffice 3.5
    """
    NARROW_GENITIVE_MONTH_NAME: Literal[19]
    """
    Narrow possessive genitive case month name.
    
    **since**
    
        LibreOffice 3.5
    """
    SHORT_PARTITIVE_MONTH_NAME: Literal[20]
    """
    Abbreviated partitive case month name.
    
    **since**
    
        LibreOffice 3.5
    """
    LONG_PARTITIVE_MONTH_NAME: Literal[21]
    """
    Full partitive case month name.
    
    **since**
    
        LibreOffice 3.5
    """
    NARROW_PARTITIVE_MONTH_NAME: Literal[22]
    """
    Narrow partitive case month name.
    
    **since**
    
        LibreOffice 3.5
    """
    NARROW_DAY_NAME: Literal[23]
    """
    Day of week, narrow name.
    
    **since**
    
        LibreOffice 3.5
    """
    NARROW_MONTH_NAME: Literal[24]
    """
    Narrow month name.
    
    **since**
    
        LibreOffice 3.5
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class StrokeAttributes(object):
    """
    Struct Class

    This structure contains all attributes required for path stroking.
    
    Path stroking is the process of drawing a polygon with a thick pen. The various attributes contained in this structure can be used to customize that process.

    See Also:
        `API StrokeAttributes <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1StrokeAttributes.html>`_
    """
    typeName: Literal['com.sun.star.rendering.StrokeAttributes']

    def __init__(self, DashArray: typing.Optional[typing.Tuple[float, ...]] = ..., LineArray: typing.Optional[typing.Tuple[float, ...]] = ..., StrokeWidth: typing.Optional[float] = ..., MiterLimit: typing.Optional[float] = ..., StartCapType: typing.Optional[int] = ..., EndCapType: typing.Optional[int] = ..., JoinType: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            DashArray (typing.Tuple[float, ...], optional): DashArray value.
            LineArray (typing.Tuple[float, ...], optional): LineArray value.
            StrokeWidth (float, optional): StrokeWidth value.
            MiterLimit (float, optional): MiterLimit value.
            StartCapType (int, optional): StartCapType value.
            EndCapType (int, optional): EndCapType value.
            JoinType (int, optional): JoinType value.
        """


    @property
    def DashArray(self) -> typing.Tuple[float, ...]:
        """
        Array of ink on and off lengths, measured in user coordinate space.
        
        The first element specifies the length of the first \"on\" segment of the dashing, the second element the length of the first \"off\" segment, and so forth. Give zero elements here for solid strokes. This array always have an even number of elements, with zero, as usual, counting as even here. Furthermore, each entry in this array must have a value that is positive (or 0.0)
        """


    @property
    def LineArray(self) -> typing.Tuple[float, ...]:
        """
        Array of line widths and spacings for multiple-line strokes.
        
        The entries here are relative to the StrokeAttributes.StrokeWidth attribute above, i.e. the total width of all lines and spacings will always equal StrokeAttributes.StrokeWidth. The first element specifies the width of the rightmost line, when traveling from the start point of the path to the end point. The second element specifies the space between the first line and the second line, and so forth. If the array ends with a spacing, this spacing is included in the total width of the multiple-line stroke. That is, the stroke becomes asymmetric.
        """


    @property
    def StrokeWidth(self) -> float:
        """
        Defines the width of the stroke, measured in user coordinate space.
        
        This value must be positive (or 0.0)
        """


    @property
    def MiterLimit(self) -> float:
        """
        Determines the maximal length of the diagonal in mitered corners.
        
        This attribute is only used when StrokeAttributes.JoinType is set to PathJoinType.MITER. Should the length of a corner's diagonal exceed this limit, a beveled join is used instead. This value must be positive (or 0.0, which is equivalent to setting StrokeAttributes.JoinType to PathJoinType.BEVEL.
        
        Before performing the actual comparison, implementations will multiply the MiterLimit with the current StrokeWidth, such that, with phi being the angle between the two joining segments, MiterLimit=1/sin(phi/2.0).
        """


    @property
    def StartCapType(self) -> int:
        """
        The start shape of the stroke.
        
        The start point is the first point of every polygon of the path poly-polygon.
        """


    @property
    def EndCapType(self) -> int:
        """
        The end shape of the stroke.
        
        The end point is the last point of every polygon of the path poly-polygon.
        """


    @property
    def JoinType(self) -> int:
        """
        The join shape of the stroke.
        
        After every sub-stroke, i.e. after every line or curve segment within a single path polygon, a shape of this type is inserted into the stroke to glue the segments together. Please note that distinct polygons within the path poly-polygon are not connected, and therefore also not joined via the shape specified here.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class FontMetrics(object):
    """
    Struct Class

    Metrics global to the font, i.e.
    
    not specific to single glyphs. The font height is defined as ascent+descent+internalLeading, and therefore not explicitly included here.
    
    Please note that when querying FontMetrics from an XCanvasFont interface, all values here are given relative to the font cell size. That means, the referenceCharWidth and/or ascent+descent+internalLeading will approximately (rounded to integer device resolution, or exactly, if fractional font rendering is enabled) match the referenceAdvancement/cellSize members of the FontRequest for which the XCanvasFont was queried. Please be aware that the values returned in this structure only map one-to-one to device pixel, if the combined rendering transformation for text output equals the identity transformation. Otherwise, the text output (and thus the resulting metrics) will be subject to that transformation. Depending on the underlying font technology, actual device output might be off by up to one device pixel from the transformed metrics.
    
    **since**
    
        OOo 2.0

    See Also:
        `API FontMetrics <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1FontMetrics.html>`_
    """
    typeName: Literal['com.sun.star.rendering.FontMetrics']

    def __init__(self, Ascent: typing.Optional[float] = ..., Descent: typing.Optional[float] = ..., InternalLeading: typing.Optional[float] = ..., ExternalLeading: typing.Optional[float] = ..., ReferenceCharSize: typing.Optional[float] = ..., UnderlineOffset: typing.Optional[float] = ..., StrikeThroughOffset: typing.Optional[float] = ...) -> None:
        """
        Constructor

        Arguments:
            Ascent (float, optional): Ascent value.
            Descent (float, optional): Descent value.
            InternalLeading (float, optional): InternalLeading value.
            ExternalLeading (float, optional): ExternalLeading value.
            ReferenceCharSize (float, optional): ReferenceCharSize value.
            UnderlineOffset (float, optional): UnderlineOffset value.
            StrikeThroughOffset (float, optional): StrikeThroughOffset value.
        """


    @property
    def Ascent(self) -> float:
        """
        Ascent (above the baseline) part of the font.
        """


    @property
    def Descent(self) -> float:
        """
        Descent (below the baseline) part of the font.
        """


    @property
    def InternalLeading(self) -> float:
        """
        Extra space above ascent.
        """


    @property
    def ExternalLeading(self) -> float:
        """
        Extra space outside the font cells.
        
        It should not contain ink marks and is typically used by the font designer to modify the line distance.
        """


    @property
    def ReferenceCharSize(self) -> float:
        """
        This value specifies the reference character width of the font.
        
        It's roughly equivalent to the average width of all characters, and if one needs a font with double character width, the referenceCharSize should be doubled.
        """


    @property
    def UnderlineOffset(self) -> float:
        """
        Specifies the offset to be added to the baseline when drawing underlined text.
        """


    @property
    def StrikeThroughOffset(self) -> float:
        """
        Specifies the offset to be added to the baseline when striking through the text.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.x_popup_menu import XPopupMenu as XPopupMenu_8ee90a55

class XPopupMenuController(XInterface_8f010a43):
    """
    provides data to a pop-up menu controller implementation to fill and update a pop-up menu dynamically.
    
    A pop-up menu controller gets a com.sun.star.awt.XPopupMenu from its parent menu implementation. The controller has to fill this pop-up menu with a set of menu items and/or sub menus. The parent menu implementation briefs the controller whenever the pop-up menu gets activated by a user.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XPopupMenuController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XPopupMenuController.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XPopupMenuController']

    def setPopupMenu(self, PopupMenu: 'XPopupMenu_8ee90a55') -> None:
        """
        provides a com.sun.star.awt.XPopupMenu to a pop-up menu controller implementation.
        
        The controller must fill this pop-up menu with its functions.
        """
    def updatePopupMenu(self) -> None:
        """
        briefs the pop-up menu controller to update the contents of the provided pop-up menu to reflect the current state.
        
        A controller should never update the pop-up menu structure on its own to prevent performance problems. A better way would be that a controller registers itself as status listener to for a command URL and immediately deregister after that. Therefore status updates will not be send regularly for a non visible pop-up menu.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.table
from ..container.x_named import XNamed as XNamed_a6520b08
from ..document.x_embedded_object_supplier import XEmbeddedObjectSupplier as XEmbeddedObjectSupplier_8b631174
from .x_table_chart import XTableChart as XTableChart_ae420b42

class TableChart(XNamed_a6520b08, XEmbeddedObjectSupplier_8b631174, XTableChart_ae420b42):
    """
    Service Class

    represents a chart based on data in a table or spreadsheet.
    
    This service does not represent the chart document model itself, but the object in the table that contains this chart document.

    See Also:
        `API TableChart <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1table_1_1TableChart.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .rectangle import Rectangle as Rectangle_84b109e9
    from .x_pointer import XPointer as XPointer_7abe098d
    from .x_toolkit import XToolkit as XToolkit_7adf0992
    from ..util.color import Color as Color_68e908c5

class XWindowPeer(XComponent_98dc0ab5):
    """
    gives access to the actual window implementation on the device.

    See Also:
        `API XWindowPeer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XWindowPeer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XWindowPeer']

    def getToolkit(self) -> 'XToolkit_7adf0992':
        """
        returns the toolkit which created this object.
        """
    def invalidate(self, Flags: int) -> None:
        """
        invalidates the whole window with the specified InvalidateStyle.
        """
    def invalidateRect(self, Rect: 'Rectangle_84b109e9', Flags: int) -> None:
        """
        invalidates a rectangular area of the window with the specified InvalidateStyle.
        """
    def setBackground(self, Color: 'Color_68e908c5') -> None:
        """
        sets the background color.
        """
    def setPointer(self, Pointer: 'XPointer_7abe098d') -> None:
        """
        sets the mouse pointer.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.point import Point as Point_5fb2085e
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from ..awt.size import Size as Size_576707ef
    from .x_frame import XFrame as XFrame_7a570956
    from ..ui.docking_area import DockingArea as DockingArea_8daf0a1e
    from ..ui.x_docking_area_acceptor import XDockingAreaAcceptor as XDockingAreaAcceptor_f8d90da7
    from ..ui.xui_element import XUIElement as XUIElement_820509a6

class XLayoutManager(XInterface_8f010a43):
    """
    central interface to query for, create, destroy and manipulate user interface elements which are bound to a layout manager.
    
    Every user interface element which is controlled by a layout manager has a unique identifier called resource URL.
    
    A resource URL must meet the following syntax: \"private:resource/$type/$name\". It is only allowed to use ASCII characters for type and name.
    
    Currently the following user interface element types are defined:
    
    **since**
    
        OOo 2.0

    See Also:
        `API XLayoutManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XLayoutManager.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XLayoutManager']

    def attachFrame(self, Frame: 'XFrame_7a570956') -> None:
        """
        attaches a com.sun.star.frame.XFrame to a layout manager.
        
        A layout manager needs a com.sun.star.frame.XFrame to be able to work. Without a it no user interface elements can be created.
        """
    def createElement(self, ResourceURL: str) -> None:
        """
        creates a new user interface element.
        """
    def destroyElement(self, ResourceURL: str) -> None:
        """
        destroys a user interface element.
        """
    def doLayout(self) -> None:
        """
        forces a complete new layouting of all user interface elements.
        """
    def dockAllWindows(self, nElementType: int) -> bool:
        """
        docks all windows which are member of the provided user interface element type.
        """
    def dockWindow(self, ResourceURL: str, DockingArea: 'DockingArea_8daf0a1e', Pos: 'Point_5fb2085e') -> bool:
        """
        docks a window based user interface element to a specified docking area.
        """
    def floatWindow(self, ResourceURL: str) -> bool:
        """
        forces a window based user interface element to float.
        """
    def getCurrentDockingArea(self) -> 'Rectangle_84b109e9':
        """
        provides the current docking area size of the layout manager.
        """
    def getDockingAreaAcceptor(self) -> 'XDockingAreaAcceptor_f8d90da7':
        """
        retrieves the current docking area acceptor that controls the border space of the frame's container window.
        
        A docking area acceptor retrieved by this method is owned by the layout manager. It is not allowed to dispose this object, it will be destroyed on reference count!
        """
    def getElement(self, ResourceURL: str) -> 'XUIElement_820509a6':
        """
        retrieves a user interface element which has been created before.
        
        The layout manager instance is owner of the returned user interface element. That means that the life time of the user interface element is controlled by the layout manager. It can be disposed at every time!
        """
    def getElementPos(self, ResourceURL: str) -> 'Point_5fb2085e':
        """
        retrieves the current pixel position of a window based user interface element.
        """
    def getElementSize(self, ResourceURL: str) -> 'Size_576707ef':
        """
        retrieves the current size of a window based user interface element.
        """
    def getElements(self) -> 'typing.Tuple[XUIElement_820509a6, ...]':
        """
        retrieves all user interface elements which are currently instantiated.
        
        The layout manager instance is owner of the returned user interface elements. That means that the life time of the user interface elements is controlled by the layout manager. They can be disposed at every time!
        """
    def hideElement(self, ResourceURL: str) -> bool:
        """
        hides a user interface element.
        """
    def isElementDocked(self, ResourceURL: str) -> bool:
        """
        retrieves the current docking state of a window based user interface element.
        """
    def isElementFloating(self, ResourceURL: str) -> bool:
        """
        retrieves the current floating state of a window based user interface element.
        """
    def isElementLocked(self, ResourceURL: str) -> bool:
        """
        retrieves the current lock state of a window based user interface element.
        """
    def isElementVisible(self, ResourceURL: str) -> bool:
        """
        retrieves the current visibility state of a window based user interface element.
        """
    def isVisible(self) -> bool:
        """
        retrieves the visibility state of a layout manager.
        
        A layout manager can be set to invisible state to force it to hide all of its user interface elements. If another component wants to use the window for its own user interface elements it can use this function. This function is normally used to implement inplace editing.
        """
    def lock(self) -> None:
        """
        prohibit all layout updates until unlock is called again.
        
        This call can be used to speed up the creation process of several user interface elements. Otherwise the layout manager would calculate the layout for every creation.
        """
    def lockWindow(self, ResourceURL: str) -> bool:
        """
        locks a window based user interface element if it's in a docked state.
        """
    def requestElement(self, ResourceURL: str) -> bool:
        """
        request to make a user interface element visible if it is not in hidden state.
        
        If a user interface element should forced to the visible state XLayoutManager.showElement() should be used. This function can be used for context dependent elements which should respect the current visibility state.
        """
    def reset(self) -> None:
        """
        resets the layout manager and remove all of its internal user interface elements.
        
        This call should be handled with care as all user interface elements will be destroyed and the layout manager is reset to a state after a attachFrame() has been made. That means an attached frame which has been set by attachFrame() is not released. The layout manager itself calls reset after a component has been attached or reattached to a frame.
        """
    def setDockingAreaAcceptor(self, xDockingAreaAcceptor: 'XDockingAreaAcceptor_f8d90da7') -> None:
        """
        sets a docking area acceptor that controls the border space of the frame's container window.
        
        A docking area acceptor decides if the layout manager can use requested border space for docking windows. If the acceptor denies the requested space the layout manager automatically set all docked windows into floating state and will not use this space for docking.
        After setting a docking area acceptor the object is owned by the layout manager. It is not allowed to dispose this object, it will be destroyed on reference count!
        """
    def setElementPos(self, ResourceURL: str, Pos: 'Point_5fb2085e') -> None:
        """
        sets a new position for a window based user interface element.
        
        It is up to the layout manager to decide if the user interface element can be moved. The new position can be retrieved by calling getElementPos().
        """
    def setElementPosSize(self, ResourceURL: str, Pos: 'Point_5fb2085e', Size: 'Size_576707ef') -> None:
        """
        sets a new position and size for a window based user interface element.
        
        It is up to the layout manager to decide if the user interface element can be moved and resized. The new position and size can be retrieved by calling getElementPos() and getElementSize().
        """
    def setElementSize(self, ResourceURL: str, Size: 'Size_576707ef') -> None:
        """
        sets a new size for a window based user interface element.
        
        It is up to the layout manager to decide if the user interface element can be resized. The new size can be retrieved by calling getElementSize().
        """
    def setVisible(self, Visible: bool) -> None:
        """
        sets the layout manager to invisible state and hides all user interface elements.
        
        A layout manager can be set to invisible state to force it to hide all of its user interface elements. If another component wants to use the window for its own user interface elements it can use this function. This function is normally used to implement inplace editing.
        """
    def showElement(self, ResourceURL: str) -> bool:
        """
        shows a user interface element.
        """
    def unlock(self) -> None:
        """
        permit layout updates again.
        
        This function should be called to permit layout updates. The layout manager starts to calculate the new layout after this call.
        """
    def unlockWindow(self, ResourceURL: str) -> bool:
        """
        unlocks a window based user interface element if it's in a docked state.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
"""
Const

These are the possible values for RuleTerm.RuleOperator.

See Also:
    `API RuleOperator <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1RuleOperator.html>`_
"""
CONTAINS: Literal[1]
"""
\"Contains\" - Object contains RuleTerm.Operand.
"""
CONTAINSNOT: Literal[2]
"""
\"ContainsNot\" - Object does not contain RuleTerm.Operand.
"""
GREATEREQUAL: Literal[3]
"""
\"GreaterEqual\" - Object is greater than or equal to RuleTerm.Operand.
"""
LESSEQUAL: Literal[4]
"""
\"LessEqual\" - Object is less than or equal to RuleTerm.Operand.
"""
EQUAL: Literal[5]
"""
\"Equal\" - Object is equal to RuleTerm.Operand.
"""
NOTEQUAL: Literal[6]
"""
\"NotEqual\" - Object is not equal to RuleTerm.Operand.
"""
VALUE_TRUE: Literal[7]
"""
\"True\" - Object has the value TRUE.
"""
VALUE_FALSE: Literal[8]
"""
\"False\" - Object has the value FALSE.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XResultSetUpdate(XInterface_8f010a43):
    """
    provides the possibility to write changes made on a result set back to database.

    See Also:
        `API XResultSetUpdate <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XResultSetUpdate.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdbc.XResultSetUpdate']

    def cancelRowUpdates(self) -> None:
        """
        cancels the updates made to a row.
        
        This method may be called after calling an updateXXX method(s) and before calling com.sun.star.sdbc.XResultSetUpdate.updateRow() to rollback the updates made to a row. If no updates have been made or updateRow has already been called, then this method has no effect.

        Raises:
            SQLException: ``SQLException``
        """
    def deleteRow(self) -> None:
        """
        deletes the current row from the result set and the underlying database.
        
        Cannot be called when on the insert row.

        Raises:
            SQLException: ``SQLException``
        """
    def insertRow(self) -> None:
        """
        inserts the contents of the insert row into the result set and the database.
        
        Must be on the insert row when this method is called.

        Raises:
            SQLException: ``SQLException``
        """
    def moveToCurrentRow(self) -> None:
        """
        moves the cursor to the remembered cursor position, usually the current row.
        
        This method has no effect if the cursor is not on the insert row.

        Raises:
            SQLException: ``SQLException``
        """
    def moveToInsertRow(self) -> None:
        """
        moves the cursor to the insert row.
        
        The current cursor position is remembered while the cursor is positioned on the insert row.
        
        The insert row is a special row associated with an updatable result set. It is essentially a buffer where a new row may be constructed by calling the updateXXX methods prior to inserting the row into the result set.
        
        Only the updateXXX , getXXX , and com.sun.star.sdbc.XResultSetUpdate.insertRow() methods may be called when the cursor is on the insert row. All of the columns in a result set must be given a value each time this method is called before calling insertRow . The method updateXXX must be called before a getXXX method can be called on a column value.

        Raises:
            SQLException: ``SQLException``
        """
    def updateRow(self) -> None:
        """
        updates the underlying database with the new contents of the current row.
        
        Cannot be called when on the insert row.

        Raises:
            SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...._pyi.xml.dom.events.event_exception import EventException as EventException
from ...._pyi.xml.dom.events.x_document_event import XDocumentEvent as XDocumentEvent
from ...._pyi.xml.dom.events.x_event import XEvent as XEvent
from ...._pyi.xml.dom.events.x_event_listener import XEventListener as XEventListener
from ...._pyi.xml.dom.events.x_event_target import XEventTarget as XEventTarget
from ...._pyi.xml.dom.events.x_mouse_event import XMouseEvent as XMouseEvent
from ...._pyi.xml.dom.events.x_mutation_event import XMutationEvent as XMutationEvent
from ...._pyi.xml.dom.events.xui_event import XUIEvent as XUIEvent



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text.textfield.docinfo
from ...text_field import TextField as TextField_90260a56

class PrintDateTime(TextField_90260a56):
    """
    Service Class

    specifies service of a text field that provides information about the date and time the document was last printed.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API PrintDateTime <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1PrintDateTime.html>`_
    """
    @property
    def CurrentPresentation(self) -> str:
        """
        contains the current content of the text field.
        
        This property is especially useful for import/export purposes.
        """
    @property
    def DateTimeValue(self) -> float:
        """
        contains the date and time as double value.
        """
    @property
    def IsDate(self) -> bool:
        """
        If this flag is set to TRUE this field represents, a date with an optional time.
        
        If it is set to FALSE only the time is used here.
        """
    @property
    def IsFixed(self) -> bool:
        """
        If this flag is set to false the author will be overridden by the current author each time the document is saved.
        
        If this flag is set to FALSE the date or time is always displayed as the current date or time.
        
        **since**
        
            OOo 1.1.2
        """
    @property
    def IsFixedLanguage(self) -> bool:
        """
        determines whether changes in language attributes at the position the text field is located also change the number format as appropriate for this language.
        """
    @property
    def NumberFormat(self) -> int:
        """
        this is the number format for this field.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API FillRule <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering.html#a9a534b0377c9ca41983d53b0dae0d5a4>`_
"""

EVEN_ODD: 'uno.Enum'
"""
Fill every area, where, when traveling along a line, an uneven number of intersections with polygon edges have happened.
"""
NON_ZERO: 'uno.Enum'
"""
Fill every area, where, when traveling along a line, the summed winding number (that is, -1 for a counter-clockwise-oriented polygon, and +1 for a clockwise-oriented) is non-zero.

For example, a poly-polygon consisting of two concentric circles with similar orientation is filled the same way as if only the outer circle would exist. If both have opposite orientation, then the filled representation looks the same as if filled with the EVEN_ODD fill rule.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.inspection
import typing
from .x_object_inspector_model import XObjectInspectorModel as XObjectInspectorModel_9077119b

class ObjectInspectorModel(XObjectInspectorModel_9077119b):
    """
    Service Class

    describes a default implementation of an ObjectInspectorModel
    
    This service simplifies usage of an ObjectInspector.
    
    The XObjectInspectorModel implemented by this service will not provide any property categories, nor apply any particular order to the properties provided by its handler(s).
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API ObjectInspectorModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1inspection_1_1ObjectInspectorModel.html>`_
    """
    def createDefault(self) -> None:
        """
        creates a default ObjectInspectorModel, whose one and only handler factory creates a GenericPropertyHandler.
        """
    def createWithHandlerFactories(self, handlerFactories: 'typing.Tuple[object, ...]') -> None:
        """
        creates a default ObjectInspectorModel, using an externally provided sequence of property handler factories.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def createWithHandlerFactoriesAndHelpSection(self, handlerFactories: 'typing.Tuple[object, ...]', minHelpTextLines: int, maxHelpTextLines: int) -> None:
        """
        creates a default ObjectInspectorModel, using an externally provided sequence of property handler factories, and describing an ObjectInspector which has a help section.
        
        **since**
        
            OOo 2.2

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XViewFreezable(XInterface_8f010a43):
    """
    enables a SpreadsheetView to freeze columns and rows of the view.

    See Also:
        `API XViewFreezable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XViewFreezable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XViewFreezable']

    def freezeAtPosition(self, nColumns: int, nRows: int) -> None:
        """
        freezes panes with the specified number of columns and rows.
        
        To freeze only horizontally, specify nRows as 0. To freeze only vertically, specify nColumns as 0.
        """
    def hasFrozenPanes(self) -> bool:
        """
        returns TRUE if the view has frozen panes.
        
        Only one of XViewSplitable.getIsWindowSplit() and XViewFreezable.hasFrozenPanes() can be TRUE.
        """

